mlpy package
============

.. automodule:: mlpy
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   mlpy.automl
   mlpy.backends
   mlpy.callbacks
   mlpy.cli
   mlpy.core
   mlpy.deploy
   mlpy.feature_store
   mlpy.filters
   mlpy.integrations
   mlpy.interpretability
   mlpy.lazy
   mlpy.learners
   mlpy.measures
   mlpy.model_registry
   mlpy.monitoring
   mlpy.parallel
   mlpy.persistence
   mlpy.pipelines
   mlpy.predictions
   mlpy.registry
   mlpy.resamplings
   mlpy.rl
   mlpy.serialization
   mlpy.tasks
   mlpy.tracking
   mlpy.tuning
   mlpy.utils
   mlpy.validation
   mlpy.vision
   mlpy.visualization
   mlpy.visualizations

Submodules
----------

.. toctree::
   :maxdepth: 4

   mlpy.base
   mlpy.benchmark
   mlpy.benchmark_advanced
   mlpy.prediction
   mlpy.resample
